# HOWTO use it:
# 1. Go to the directory containing this file
# 2. Start R 
# 3. Type: source('plot_attr_similarity_matrix.R'); plot.attr.similarity.matrix(data)

source('libs.R')

data <- read.table(file='/home/woznica/RM/toulouse,May,2011/data/data-gene-correlation.csv', header=T, sep=';', na.string='?')

plot.attr.similarity.matrix <- function(data=data, what='', type='cov') {
# Plots an attribute similarity matrix computed from the provided data frame. 
# The input dataset is prepared in the "prepare-gene-correlation" RM workflow and is assumed 
# to contain genes as rows, and gene functions and locations as columns. In the visualized matrix 
# columns correspond to gene locations and rows correspond to gene functions.
# The supported types of attribute similarities are: the covariance, the Hamming distance, 
# and a modified Hamming distance that focuses on columns with 1s.
#
# Args:
#   data: input data frame with genes as rows and genes' characteristics as columns. First five columns
#		are assumed to correspond to gene locations, all the remaining columns are genes' functions.
#   what: focus on gene functions that contain a specific string
#   type : what type of similarity matrix to visualize, possible options are: "cov" (covariance matrix), 
#		"hamming" (Hamming distance) and "ones" (a modified hamming distance that focuses on columns with 1s)
#
# Returns:
# 

d <- dim(data)

TYPES <- c("cov", "hamming", "ones")
type <- pmatch(type, TYPES)
if (is.na(type)) 
	stop("invalid distance type")
if (type == -1) 
	stop("ambiguous distance type")

if (type == 1) {
	c <- cov(data)
} else if (type == 2) {
	library('e1071')
	c <- hamming.distance(t(as.matrix(data))) / d[1]
} else if (type == 3) {
	c <- matrix(0, nrow=d[2], ncol=d[2], dimnames=list(names(data), names(data)))
	for (i in 1:d[2]) {
		c[i,] <- sapply(1:d[2], function(j) { length(intersect(which(data[,i]  == 1), which(data[,j] == 1) )) })
	}
}

if (what == '') {
	yrange <- 6:d[2]
} else {
	yrange <- grep(what, names(data[,6:d[2]]))
	if (length(yrange) == 0) stop(paste("No genes with names containing", what))
}

# normalize
a <- c[1:5,yrange]
if (type == 'ones') {
	for (i in 1:5) {
		a[i,] <- a[i,] / max(a[i,])
	}
}
o <- order(a[1,], a[2,], a[3, ], a[4, ])
myImagePlot(t(a[,o]), xLabels=names(data)[1:5], yLabels=names(data)[yrange], xlab="locations", ylab="functions") 

}

