# HOWTO use it:
# 1. Go to the directory containing this file
# 2. Start R 
# 3. Type: source('plot_fibrosis.R'); plot.fibrosis(data)

library("gplots")

data <- read.table(file='/home/woznica/RM/toulouse,May,2011/data/data-fibrosis-genes.csv', header=T, sep=';', na.string='?')

plot.fibrosis <- function(data=data) {
# Plots a (modified) heatmap of the fibrosis gene data describing different genes used in various studies on 
# fibrosis (currently 3 studies). The input dataset is prepared in the "prepare-fibrosis-data" RM workflow. Possible 
# values in the input data are: 1 (a gene is Up regulated), -1 (Down regulated), 0 (Unmodified) and -2 (missing value). 
#
# Args:
#   data: input data frame where rows correspond to genes and columns to different studies. 
#
# Returns:
# 
	row.names(data) <- data[,'id']
	data <- data[,-4]
	data[is.na(data)] <- -2
	col=c('grey', 'blue','black', 'red')
	heatmap.2(as.matrix(data), col=col, Rowv = T, density.info="none", scale="none") 
}


# Selects specific genes. 
#
# Args:
#   data: input data frame where rows correspond to genes and columns to different studies. 
#   d1, d2, d3 : values (-2, -1, -, 1).
#
# Returns:
#   Names of genes that have specific Up/Down regulation pattern.
#
sel.genes <- function(data=data, d1, d2, d3) {
	row.names(data[(data[,1] == d1) & (data[,2] == d2) & (data[,3] == d3), ])
}

